[![pipeline status](https://gitlab.com/l3p-cv/lost_ds/badges/master/pipeline.svg)](https://gitlab.com/l3p-cv/lost_ds/pipelines)
<!-- [![Documentation Status](https://readthedocs.org/projects/lost_ds/badge/?version=latest)](https://lost_ds.readthedocs.io/en/latest/?badge=latest) -->

### LOSTDataset

This is a library to handle datasets generated by LOST.

### Progress (modules)
- [x] io
- [x] functional
- [x] copy
- [x] geometry
- [x] cropping
- [x] vis
- [ ] segmentation
    - [ ] seg to anno
    - [x] semantic segmentation
    - [ ] instance segmentation
    - [ ] panoptic segmentation
- [x] detection
- [ ] reporting
- [ ] masking
